@@ -1,5 +1,4 @@
-#!/usr/bin/env python
-from nose.tools import *
+from nose.tools import assert_equal
 import networkx as nx
 
 
@@ -12,11 +11,11 @@ class TestBFS:
         self.G = G
 
     def test_successor(self):
-        assert_equal(nx.bfs_successors(self.G, source=0),
+        assert_equal(dict(nx.bfs_successors(self.G, source=0)),
                      {0: [1], 1: [2, 3], 2: [4]})
 
     def test_predecessor(self):
-        assert_equal(nx.bfs_predecessors(self.G, source=0),
+        assert_equal(dict(nx.bfs_predecessors(self.G, source=0)),
                      {1: 0, 2: 1, 3: 1, 4: 2})
 
     def test_bfs_tree(self):
