@@ -133,15 +133,15 @@ def _preprocess_graph(G, weight):
         H = nx.MultiGraph()
         H.add_nodes_from(G)
         H.add_weighted_edges_from(((u, v, e.get(weight, 1.))
-                                   for u, v, e in G.edges_iter(data=True)
+                                   for u, v, e in G.edges(data=True)
                                    if u != v), weight=weight)
         G = H
     if not G.is_multigraph():
         edges = ((u, v, abs(e.get(weight, 1.)))
-                 for u, v, e in G.edges_iter(data=True) if u != v)
+                 for u, v, e in G.edges(data=True) if u != v)
     else:
         edges = ((u, v, sum(abs(e.get(weight, 1.)) for e in G[u][v].values()))
-                 for u, v in G.edges_iter() if u != v)
+                 for u, v in G.edges() if u != v)
     H = nx.Graph()
     H.add_nodes_from(G)
     H.add_weighted_edges_from((u, v, e) for u, v, e in edges if e != 0)
@@ -190,7 +190,6 @@ def _tracemin_fiedler(L, X, normalized, tol, method):
             for j in range(X.shape[1]):
                 X[:, j] -= dot(X[:, j], e) * e
 
-
     if method is None:
         method = 'pcg'
     if method == 'pcg':
@@ -268,6 +267,7 @@ def _get_fiedler_func(method):
     match = _tracemin_method.match(method)
     if match:
         method = match.group(1)
+
         def find_fiedler(L, x, normalized, tol):
             q = 2 if method == 'pcg' else min(4, L.shape[0] - 1)
             X = asmatrix(normal(size=(q, L.shape[0]))).T
