@@ -1,16 +1,18 @@
 #!/usr/bin/env python
 """
+=================
+Pygraphviz Simple
+=================
+
 An example showing how to use the interface to the pygraphviz
 AGraph class to convert to and from graphviz.
 
 Also see the pygraphviz documentation and examples at
 http://pygraphviz.github.io/
-
-
 """
 # Author: Aric Hagberg (hagberg@lanl.gov)
 
-#    Copyright (C) 2006-2016 by
+#    Copyright (C) 2006-2017 by
 #    Aric Hagberg <hagberg@lanl.gov>
 #    Dan Schult <dschult@colgate.edu>
 #    Pieter Swart <swart@lanl.gov>
@@ -28,5 +30,4 @@ X2 = nx.Graph(A)          # fancy way to do conversion
 G1 = nx.Graph(X1)          # now make it a Graph
 
 A.write('k5.dot')     # write to dot file
-X3 = nx.nx_agraph.read_dot('k5.dot') # read from dotfile
-
+X3 = nx.nx_agraph.read_dot('k5.dot')  # read from dotfile
